@@ -155,7 +155,8 @@ enum XNEE_OPTION_KEYS
     XNEE_EXT_REP_MIN_STR_KEY  ,
     XNEE_RETYPE_PRESS_DELAY   ,
     XNEE_RETYPE_RELEASE_DELAY ,
-    XNEE_NO_REPARENT_RECORD 
+    XNEE_NO_REPARENT_RECORD   ,
+    XNEE_MAX_WINDOW_MOVES
   };
 
 
